# softnanotools

This repository contains a bunch of tools for different programming applications, mostly in Python. It is used through the [softnanolab](https://softnanolab.org/) research group

## Installation

The package uses only the Python standard library so the only prerequisite is the use of Python 3.

Installing using:

```sh
# pip
pip install softnanotools

# manual
git clone https://github.com/softnanolab/softnanotools
pip install ./softnanotools
```

## Modules

Here is a list of modules with a brief description:

- `notebooks` - Tools for manipulating Jupyter Notebooks
- `logger` - A logger that prints to screen
- `runner` - A tool for organising the execution of programs
